@@ -2,9 +2,10 @@ from tradingview_scraper import *
 
 a = ClassA.scraper(symbol = 'btc',
                 wholePage = False,
-                stratPage = 1,
+                startPage = 1,
                 endPage = 2, 
-                to_csv = False)
+                to_csv = False,
+                return_json=True)
 
-print(type(a))
-print(a[0])
\ No newline at end of file
+# print(a)
+print(a.keys())
\ No newline at end of file
